    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      b      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              z   4                     Gjuliac-buildscript A427R7F42H ~ BQoPG}G>                    XcCp0@Js5IN                            juliac-buildscript                    
*Hcd                   
*Hcd
                
subject.OU        
A427R7F42H                4                      Gjuliac-buildscript A427R7F42H +R( 7#u9JPi                                B'G\,vke1wŬ6haq
by-\J0	*H
010
	`He 0	*H
  0>0& ?͗Iz˃Mxs]C0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
210922185510Z
310917000000Z0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0"0
	*H
  0
 ,h!TeqN
(uRDހFg) 0MLnJcLB/}%_K*To0)(4x]#*!FЉ_jq
5-'!@r7v1tpL-^Eb@7\ܥP@
#%E@g{9x43.,&%Ϊ*w_.q;Lz"Mpֆg33Z@Īs\7 00U0 0U#0+iGv	k.@GM^0D+80604+0(http://ocsp.apple.com/ocsp03-applerootca0.U'0%0#!http://crl.apple.com/root.crl0U:ivY7U0U0
*Hcd 0
	*H
  C
YCZ20V&Hc+irH[^&t#3T3"ZظKiΖ
5joΊibmJ9MעԈ3\7D7Dh
{}~̵o=zt}҈1Y`F잹@*a
pJ,Lyc%!#o[ZWEm_doD/oM=xx
V;:+eXԹ02M$9:Z\000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00!u	LrZ=0
	*H
 0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0
240912150650Z
290913150649Z010
	&,d
A427R7F42H1C0AU:Developer ID Application: Julia Computing LLC (A427R7F42H)10U
A427R7F42H10U
Julia Computing LLC10	UUS0"0
	*H
  0
 IXTVC#$
T'D`qz5c۾Lt<-ލ^R4}Gwb"BϻI٩#5=qQ_Û3(*5%b,4N	#4BMoW_ŦfL8NDJ=u"C[v8`ch%;K3ȏA'}mTl" ߲shCg]v<8i]`2Ea3/ZHLi F0B0U0 0U#0:ivY7U0r+f0d0.+0"http://certs.apple.com/devidg2.der02+0&http://ocsp.apple.com/ocsp03-devidg2010U 00
	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.07++https://www.apple.com/certificateauthority/0U%0
+0UWmDl.?^0U0
*Hcd!20140811000000Z0
*Hcd
 0
	*H
  u8V(j+FmX 0:M<Rz/<q.(ߡz=$Z-h
ׯ(ǁ4SYm$P`Δw,,ؗ'MtD!N
\F
W)ZZKxwME
Y(j9\@DztB@`V**$g߼gy;g~0Lӧ=@X#Y
ӢFZ&N1qHу!ID}ᾡ0/v|req5O+/N1Aҙ100r0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS!u	LrZ=0
	`He %0	*H
	1	*H
0	*H
	1
251017142243Z0/	*H
	1" ){AL
/x39?Æp0[	*Hcd	1N0+2?S#?
v0-	`He  [zy9P:w
-ZpU40[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		lhrS5wwyP7FTIx7BPxjf5w33GHY=
		</data>
		<data>
		nSDeDFt6eec5mgHYUBoHp4866Xc=
		</data>
	</array>
</dict>
</plist>
0
	*H
  D*6Kˎy*J)(Eh /񲕢/FSHlO̜" 6Ã+Հbp$hG4

o-5yjis3')Y8ȤT] i+A9\y]pbuvځT'OU3J/q-&Z|-t׿=lB lMJo5Tjz{EQV[`˶öP]z8B;0 $}.C`^10R20*H
	10	*H
010	+ 0{*H
	lj0h*010
	`He  CI	uN^":5NV/톗 hH>W)G20251017142244Z0	 {Dꟛ
00oz0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
251013173520Z
251124173519Z0A10UTimestamp Signer MA210U

Apple Inc.10	UUS0"0
	*H
  0
 Alv
]kZF) $
	vy5*CQNsS;!!f5RUB*,7+BﴚdW;
6Ƕڀ7dɉx&q{
aws/(DI-G9@87lgHD"!ͽO#A˳p?U1+.ɶޒM4gm
nr#P(@Lu 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U|"Pߢ_\Vd0U0
	*H
  #h,&[a'E'Rb4"IPrmoW5ROt(Yr?qKkz%cH[E$mQTgM%fi:c*ũ)!@涪
R@[YQu:w߲TL>H愀)WrHX76RV[8lmzDɒwN~~֭2twātӀ&N}VV~D00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSoz0	+ 0	*H
	1
*H
	0	*H
	1
251017142244Z0#	*H
	1i%_7vJwB]0+*H
	1000-(tWY#ţg	7M0
	*H
  	'[ %۔S3$13S}: ]8!Do,azsL#fTTg}޿PUаrXIzC_Z.
XFᕑ]u#,]1S4W0B
pU#<k*g<ug~5`:H ]gS
\cK҃qs*iR#N0yx=eF
vXW elNoe<ĐIY|q      